@@ -8,6 +8,7 @@
 """
 from relief.constants import Unspecified, NotUnserializable
 from relief.schema.core import Element
+from relief.schema.meta import Maybe
 from relief.schema.scalars import (
     Boolean, Integer, Float, Complex, Unicode, Bytes
 )
@@ -15,8 +16,8 @@ from relief.schema.mappings import Dict, OrderedDict, Form
 from relief.schema.sequences import Tuple, List
 
 
-__version__ = "2.0.0"
-__version_info__ = (2, 0, 0)
+__version__ = "2.1.0"
+__version_info__ = (2, 1, 0)
 
 
 __all__ = [
@@ -29,5 +30,7 @@ __all__ = [
     # mappings
     "Dict", "OrderedDict", "Form",
     # sequences
-    "Tuple", "List"
+    "Tuple", "List",
+    # meta
+    "Maybe"
 ]
